import time
import traceback
from base64 import b64decode, b64encode
from pathlib import Path

import orjson
from nonebot.log import logger

from ..data_source import config
from ..HttpClient_pool import client_default, client_yuyuko

ocr_url = config.ocr_url
dir_path = Path(__file__).parent.parent
game_path = Path(__file__).parent
ocr_data_path = game_path / "ocr_data.json"
upload_url = "https://api.wows.shinoaki.com/api/wows/cache/image/ocr"
download_url = "https://api.wows.shinoaki.com/api/wows/cache/image/ocr"

async def pic2txt_byOCR(img_path, filename):
    try:
        global ocr_filename_data
        if filename in ocr_filename_data:
            logger.success(f"filename匹配，跳过OCR:{filename}")
            return b64decode(ocr_filename_data[filename]).decode("utf-8")
        if config.ocr_offline:
            return ""
        start = time.time()
        params = {"url": img_path}
        resp = await client_default.post(
            f"{ocr_url}/OCR/", data=params, timeout=5, follow_redirects=True
        )
        end = time.time()
        result = orjson.loads(resp.content)
        if result['code'] == 200:
            logger.success(f"OCR结果：{result['data']['msg']},耗时{end-start:.4f}s\n图片url:{img_path}")
            return result['data']['msg']
    except:
        logger.error(traceback.format_exc())
        return ""


async def upload_OcrResult(result_text, filename):
    try:
        params = {
            "md5": filename,
            "text": b64encode(result_text.encode("utf-8")).decode("utf-8"),
        }
        resp = await client_yuyuko.post(upload_url, json=params)
        result = orjson.loads(resp.content)
        if result["code"] == 200:
            await downlod_OcrResult()
    except:
        logger.error(traceback.format_exc())


async def downlod_OcrResult():
    try:
        global ocr_filename_data
        resp = await client_yuyuko.get(download_url)
        result = orjson.loads(resp.content)
        with open(ocr_data_path, "w", encoding="UTF-8") as f:
            if result["code"] == 200 and result["data"]:
                f.write(orjson.dumps(result['data']).decode())
                ocr_filename_data = result["data"]
            else:
                with open(ocr_data_path, "rb") as f:    
                    ocr_filename_data = orjson.loads(f.read())
        return
    except:
        logger.error("请检查token是否配置正确，如无问题请尝试重启，可能是网络波动或服务器原因")
        logger.error(traceback.format_exc())
        try:
            with open(ocr_data_path, "rb") as f:    
                ocr_filename_data = orjson.loads(f.read())
        except:
            ocr_filename_data = None


async def get_Random_Ocr_Pic(server_type, info, bot, ev):
    try:
        resp = await client_default.post(f"{ocr_url}/ImageRandom/")
        img = b64decode(resp.text)
        return img
    except:
        logger.error(traceback.format_exc())  
        return 'OCR服务器出了点问题，请稍后再试哦' 
        


import asyncio
import html
import os
import platform
import random
import re
import sys
import traceback

import httpx
import orjson
from loguru import logger
from nonebot import get_driver, on_command, on_fullmatch, on_message, require
from nonebot.adapters.onebot.v11 import (
    ActionFailed,
    Bot,
    GroupMessageEvent,
    Message,
    MessageEvent,
    MessageSegment,
    PrivateMessageEvent,
)
from nonebot.log import logger
from nonebot.params import CommandArg
from nonebot.permission import SUPERUSER
from nonebot_plugin_guild_patch import GuildMessageEvent
from nonebot_plugin_htmlrender import text_to_pic

from .command_select import select_command
from .data_source import nb2_file, template_path
from .game.ocr import downlod_OcrResult, pic2txt_byOCR, upload_OcrResult
from .game.pupu import get_pupu_msg
from .HttpClient_pool import client_default, client_yuyuko
from .moudle.wws_clan import ClanSecletProcess
from .moudle.wws_ship import ShipSecletProcess
from .utils import DailyNumberLimiter, FreqLimiter, download, get_bot

scheduler = require("nonebot_plugin_apscheduler").scheduler

_max = 100
EXCEED_NOTICE = f"您今天已经冲过{_max}次了，请明早5点后再来！"
is_first_run = True
_nlmt = DailyNumberLimiter(_max)
_flmt = FreqLimiter(3)
__version__ = "0.3.9"

bot = on_command("wws", block=False, aliases={"WWS"}, priority=54)
bot_pupu = on_fullmatch("噗噗", block=False, priority=5)
bot_checkversion = on_command("wws 检查更新", priority=5, block=False)
bot_update = on_command("wws 更新Hikari", priority=5, block=False, permission=SUPERUSER)
bot_listen = on_message(priority=5, block=False)
ocr_listen = on_message(priority=6, block=False)
driver = get_driver()


@bot.handle()
async def main(bot: Bot, ev: MessageEvent, matchmsg: Message = CommandArg()):
    try:
        server_type = None
        if isinstance(ev, PrivateMessageEvent) and (
            driver.config.private or str(ev.user_id) in driver.config.superusers
        ):  # 私聊事件,superusers默认不受影响
            server_type = "QQ"
        elif (
            isinstance(ev, GroupMessageEvent)
            and driver.config.group
            and ev.group_id not in driver.config.ban_group_list
        ):  # 群聊事件
            server_type = "QQ"
        elif isinstance(ev, GuildMessageEvent) and driver.config.channel:  # 频道事件
            if driver.config.all_channel or ev.channel_id in driver.config.channel_list:
                server_type = "QQ_CHANNEL"
            else:
                return False
        else:
            return False
        msg = ""
        qqid = ev.user_id
        replace_name = None
        if not _nlmt.check(qqid):
            await bot.send(ev, EXCEED_NOTICE, at_sender=True)
            return False
        if not _flmt.check(qqid):
            await bot.send(ev, "您冲得太快了，请稍候再冲", at_sender=True)
            return False
        _flmt.start_cd(qqid)
        _nlmt.increase(qqid)
        if random.randint(1,1000) == 1:
            await bot.send(ev, "一天到晚惦记你那b水表，就nm离谱")
            return False
        searchtag = html.unescape(str(matchmsg)).strip()
        if not searchtag:
            await bot.send(ev, "请发送wws help查看相关帮助")
            return False
        if searchtag == "help":
            msg = await send_bot_help()
            await bot.send(ev, MessageSegment.image(msg))
            return True
        match = re.search(r"(\(|（)(.*?)(\)|）)", searchtag)
        if match:
            replace_name = match.group(2)
            search_list = searchtag.replace(match.group(0), "").split()
        else:
            search_list = searchtag.split()
        command, search_list = await select_command(search_list)
        if replace_name:
            search_list.append(replace_name)
        msg = await command(server_type, search_list, bot, ev)
        if msg:
            if isinstance(msg, str):
                await bot.send(ev, msg)
                return True
            else:
                await bot.send(ev, MessageSegment.image(msg))
                return True
        else:
            await bot.send(ev, "没有获取到数据，可能是内部问题")
            return False
    except ActionFailed:
        logger.warning(traceback.format_exc())
        try:
            await bot.send(ev, "发不出图片，可能被风控了QAQ")
            return True
        except Exception:
            pass
        return False
    except Exception:
        logger.error(traceback.format_exc())
        await bot.send(ev, "呜呜呜发生了错误，可能是网络问题，如果过段时间不能恢复请联系麻麻哦~")


async def send_bot_help():
    try:
        url = "https://benx1n.oss-cn-beijing.aliyuncs.com/version.json"
        resp = await client_default.get(url, timeout=10)
        result = orjson.loads(resp.text)
        latest_version = result["latest_version"]
        url = "https://benx1n.oss-cn-beijing.aliyuncs.com/wws_help.txt"
        resp = await client_default.get(url, timeout=10)
        result = resp.text
        result = f"""帮助列表                                                当前版本{__version__}  最新版本{latest_version}\n{result}"""
        img = await text_to_pic(
            text=result, css_path=str(template_path / "text-help.css"), width=800
        )
        return img
    except Exception:
        logger.warning(traceback.format_exc())
        return "wuwuwu出了点问题，请联系麻麻解决"


@bot_listen.handle()
async def change_select_state(ev: MessageEvent):
    try:
        bot = get_bot()
        msg = str(ev.message)
        qqid = ev.user_id
        if ShipSecletProcess[qqid].SelectList and str(msg).isdigit():
            if int(msg) <= len(ShipSecletProcess[qqid].SelectList):
                ShipSecletProcess[qqid] = ShipSecletProcess[qqid]._replace(state=True)
                ShipSecletProcess[qqid] = ShipSecletProcess[qqid]._replace(
                    SlectIndex=int(msg)
                )
            else:
                await bot.send(ev, "请选择列表中的序号哦~")
        if ClanSecletProcess[qqid].SelectList and str(msg).isdigit():
            if int(msg) <= len(ClanSecletProcess[qqid].SelectList):
                ClanSecletProcess[qqid] = ClanSecletProcess[qqid]._replace(state=True)
                ClanSecletProcess[qqid] = ClanSecletProcess[qqid]._replace(
                    SlectIndex=int(msg)
                )
            else:
                await bot.send(ev, "请选择列表中的序号哦~")
    except Exception:
        logger.warning(traceback.format_exc())
        return


@ocr_listen.handle()
async def OCR_listen(bot: Bot, ev: MessageEvent):
    try:
        import time

        if not driver.config.ocr_on:
            return
        if not (str(ev.message).find("[CQ:image") + 1):  # 判断收到的信息是否为图片，不是就退出
            return
        tencent_url = ""
        for seg in ev.message:
            if seg.type == "image":
                tencent_url = seg.data["url"]
                filename = str(seg.data["file"]).replace(".image", "")
        ocr_text = await pic2txt_byOCR(tencent_url, filename)
        if ocr_text:
            match = re.search(r"^(/?)wws(.*?)$", ocr_text)
            if match:
                searchtag = re.sub(r"^(/?)wws", "", ocr_text)  # 删除wws和/wws
                is_send = await main(bot, ev, searchtag)
                if is_send:
                    await upload_OcrResult(ocr_text, filename)
    except Exception:
        logger.error(traceback.format_exc())
        return


@bot_update.handle()
async def update_Hikari(ev: MessageEvent, bot: Bot):
    try:
        from nonebot_plugin_reboot import Reloader

        await bot.send(ev, "正在更新Hikari，完成后将自动重启，如果没有回复您已上线的消息，请登录服务器查看")
        if hasattr(driver.config, "nb2_path"):
            await asyncio.gather(
                *[
                    download(each["url"], f"{driver.config.nb2_path}\{each['name']}")
                    for each in nb2_file
                ]
            )
        logger.info(f"当前解释器路径{sys.executable}")
        os.system(f"{sys.executable} -m pip install --upgrade hikari-bot")
        os.system(f"{sys.executable} -m pip install --upgrade nonebot-plugin-gocqhttp")
        Reloader.reload(delay=1)
    except RuntimeError:
        if str(platform.system()).lower() == "linux":
            try:
                import multiprocessing

                for child in multiprocessing.active_children():
                    child.terminate()
                sys.stdout.flush()
                # not compatible with cmdline with '\n'
                os.execv(
                    os.readlink("/proc/self/exe"),
                    open("/proc/self/cmdline", "rb")
                    .read()
                    .replace(b"\0", b"\n")
                    .decode()
                    .split("\n")[:-1],
                )
            except Exception:
                logger.error(traceback.format_exc())
                await bot.send(ev, "自动更新失败了QAQ，请登录服务器查看具体报错日志")
        else:
            logger.error(traceback.format_exc())
            await bot.send(ev, "不支持nb run启动的方式更新哦，请使用python bot.py 启动Hikari")
    except Exception:
        logger.error(traceback.format_exc())
        await bot.send(ev, "自动更新失败了QAQ，请登录服务器查看具体报错日志")


@bot_checkversion.handle()
async def check_version():
    try:
        bot = get_bot()
        url = "https://benx1n.oss-cn-beijing.aliyuncs.com/version.json"
        resp = await client_default.get(url, timeout=10)
        result = orjson.loads(resp.text)
        superid = driver.config.superusers
        match, msg = False, f"发现新版本"
        for each in result["data"]:
            if each["version"] > __version__:
                match = True
                msg += f"\n{each['date']} v{each['version']}\n"
                for i in each["description"]:
                    msg += f"{i}\n"
        msg += "实验性更新指令：wws 更新Hikari，请在能登录上服务器的情况下执行该命令"
        if match:
            for each in superid:
                await bot.send_private_msg(user_id=int(each), message=msg)
            try:
                await bot_checkversion.send(msg)
            except Exception:
                return
        else:
            for each in superid:
                await bot.send_private_msg(
                    user_id=int(each), message="Hikari:当前已经是最新版本了"
                )
            try:
                await bot_checkversion.send("Hikari:当前已经是最新版本了")
            except Exception:
                return
        return
    except Exception:
        logger.warning(traceback.format_exc())
        return


@driver.on_startup
async def startup():
    try:
        tasks = []
        loop = asyncio.get_running_loop()
        url = "https://benx1n.oss-cn-beijing.aliyuncs.com/template_Hikari_Latest/template.json"
        async with httpx.AsyncClient() as client:
            resp = await client.get(url, timeout=20)
            result = orjson.loads(resp.content)
            for each in result:
                for name, url in each.items():
                    tasks.append(asyncio.ensure_future(startup_download(url, name)))
        await asyncio.gather(*tasks)
        if driver.config.ocr_on:
            await downlod_OcrResult()
    except Exception:
        logger.error(traceback.format_exc())
        return


@driver.on_bot_connect
async def remind(bot: Bot):
    superid = driver.config.superusers
    bot_info = await bot.get_login_info()
    for each in superid:
        await bot.send_private_msg(
            user_id=int(each), message=f"Hikari已上线，当前版本{__version__}"
        )
    # global is_first_run
    # if is_first_run:
    #    mqtt_run(bot_info['user_id'])
    #    is_first_run = False


async def startup_download(url, name):
    async with httpx.AsyncClient() as client:
        resp = await client.get(url, timeout=20)
        with open(template_path / name, "wb+") as file:
            file.write(resp.content)


scheduler.add_job(
    check_version,
    "cron",
    hour=12,
)
scheduler.add_job(startup, "cron", hour=4)
scheduler.add_job(downlod_OcrResult, "interval", minutes=10)


@bot_pupu.handle()
async def send_pupu_msg(ev: MessageEvent, bot: Bot):
    try:
        if (
            driver.config.pupu
            and isinstance(ev, GroupMessageEvent)
            and driver.config.group
            and ev.group_id not in driver.config.ban_group_list
        ):
            msg = await get_pupu_msg()
            await bot.send(ev, msg)
    except ActionFailed:
        logger.warning(traceback.format_exc())
        try:
            await bot.send(ev, "噗噗寄了>_<可能被风控了QAQ")
        except Exception:
            pass
        return



import asyncio
import traceback
from asyncio.exceptions import TimeoutError

import jinja2
import orjson
from bs4 import BeautifulSoup
from httpx import ConnectTimeout
from nonebot.adapters.onebot.v11 import Bot, MessageSegment
from nonebot.log import logger
from nonebot_plugin_htmlrender import html_to_pic, text_to_pic

from ..data_source import (
    number_url_homes,
    servers,
    set_ShipRank_Numbers,
    set_shipSelectparams,
    template_path,
    tiers,
)
from ..HttpClient_pool import client_default, client_yuyuko
from ..utils import match_keywords
from .publicAPI import get_ship_byName
from .wws_ship import ShipSecletProcess, ShipSlectState

env = jinja2.Environment(
    loader=jinja2.FileSystemLoader(template_path), enable_async=True
)

async def get_ShipRank(server_type, info, bot:Bot, ev):
    try:
        if len(info) == 2:
            param_server, info = await match_keywords(info, servers)
            if param_server:
                number_url = number_url_homes[param_server] + "/ship/"
            else:
                return "请检查服务器是否正确"
        else:
            return "参数似乎出了问题呢"
        shipList = await get_ship_byName(str(info[0]))
        logger.success(f"{shipList}")
        if shipList:
            if len(shipList) < 2:
                select_shipId = shipList[0][0]
                shipInfo = {"shipNameCn": shipList[0][1], "tier": shipList[0][3]}
                number_url += f"{select_shipId},{shipList[0][2]}"
            else:
                ShipSecletProcess[ev.user_id] = ShipSlectState(
                        False, None, shipList
                    )
                template = env.get_template("select-ship.html")
                template_data = await set_shipSelectparams(shipList)
                content = await template.render_async(template_data)
                img = await html_to_pic(
                        content, wait=0, viewport={"width": 360, "height": 100}
                    )
                await bot.send(ev, MessageSegment.image(img))
                a = 0
                while a < 40 and not ShipSecletProcess[ev.user_id].state:
                    a += 1
                    await asyncio.sleep(0.5)
                if ShipSecletProcess[ev.user_id].state and ShipSecletProcess[
                    ev.user_id
                ].SlectIndex <= len(shipList):
                    select_shipId = int(
                        shipList[ShipSecletProcess[ev.user_id].SlectIndex - 1][0]
                    )
                    shipInfo = {
                        "shipNameCn": shipList[ShipSecletProcess[ev.user_id].SlectIndex - 1][1],
                        "tier": shipList[ShipSecletProcess[ev.user_id].SlectIndex - 1][3]
                    }
                    number_url += f"{select_shipId},{shipList[ShipSecletProcess[ev.user_id].SlectIndex-1][2]}"
                    ShipSecletProcess[ev.user_id] = ShipSlectState(False, None, None)
                else:
                    ShipSecletProcess[ev.user_id] = ShipSlectState(False, None, None)
                    return "已超时退出"
        else:
            return "找不到船，请确认船名是否正确，可以使用【wws 查船名】查询船只中英文"
        if not param_server == "cn":
            content = await search_ShipRank_Yuyuko(select_shipId, param_server, shipInfo)
            if content:  # 存在缓存，直接出图
                return await html_to_pic(
                    content, wait=0, viewport={"width": 1300, "height": 100}
                )
            else:  # 无缓存，去Number爬
                content, numbers_data = await search_ShipRank_Numbers(
                    number_url, param_server, select_shipId, shipInfo
                )
                if content:
                    await post_ShipRank(numbers_data)  # 上报Yuyuko
                    return await html_to_pic(
                        content, wait=0, viewport={"width": 1300, "height": 100}
                    )
                else:
                    return "wuwuu好像出了点问题，可能是网络问题，过一会儿还是不行的话请联系麻麻~"
        else:
            content = await search_cn_rank(select_shipId, param_server, 1, shipInfo)
            if content:
                return await html_to_pic(
                    content, wait=0, viewport={"width": 1300, "height": 100}
                )
            else:
                return "wuwuu好像出了点问题，可能是网络问题，过一会儿还是不行的话请联系麻麻~"
    except (TimeoutError, ConnectTimeout):
        logger.warning(traceback.format_exc())
        ShipSecletProcess[ev.user_id] = ShipSlectState(False, None, None)
        return "请求超时了，请过会儿再尝试哦~"
    except Exception:
        logger.error(traceback.format_exc())
        ShipSecletProcess[ev.user_id] = ShipSlectState(False, None, None)
        return "wuwuu好像出了点问题，过一会儿还是不行的话请联系麻麻~"


async def search_ShipRank_Yuyuko(shipId, server, shipInfo):
    try:
        content = None
        url = "https://api.wows.shinoaki.com/upload/numbers/data/v2/upload/ship/rank"
        params = {"server": server, "shipId": int(shipId)}
        resp = await client_yuyuko.get(url, params=params, timeout=None)
        result = orjson.loads(resp.content)
        if result["code"] == 200 and result["data"]:
            template = env.get_template("ship-rank.html")
            result_data = {"data": result["data"], "shipInfo": shipInfo}
            content = await template.render_async(result_data)
            return content
        else:
            return None
    except (TimeoutError, ConnectTimeout):
        logger.warning(traceback.format_exc())
        return None
    except Exception:
        logger.error(traceback.format_exc())
        return None


async def search_ShipRank_Numbers(url, server, shipId, shipInfo):
    try:
        content = None
        resp = await client_default.get(url, timeout=None)
        soup = BeautifulSoup(resp.content, "html.parser")
        data = soup.select('tr[class="cells-middle"]')
        infoList = await set_ShipRank_Numbers(data, server, shipId)
        if infoList:
            result_data = {"data": infoList, "shipInfo": shipInfo}
            template = env.get_template("ship-rank.html")
            content = await template.render_async(result_data)
            return content, infoList
        else:
            return None, None
    except Exception:
        logger.error(traceback.format_exc())
        return None, None


async def post_ShipRank(data):
    try:
        url = "https://api.wows.shinoaki.com/upload/numbers/data/v2/upload/ship/rank"
        resp = await client_yuyuko.post(url, json=data, timeout=None)
        result = orjson.loads(resp.content)
        logger.success(result)
    except (TimeoutError, ConnectTimeout):
        logger.warning(traceback.format_exc())
    except Exception:
        logger.error(traceback.format_exc())


async def search_cn_rank(shipId, server, page, shipInfo):
    try:
        content = None               # 查询是否有缓存
        url = "https://api.wows.shinoaki.com/wows/rank/ship/server"
        params = {"server": server, "shipId": int(shipId), "page": int(page)}
        resp = await client_yuyuko.get(url, params=params, timeout=None)
        result = orjson.loads(resp.content)
        if result["code"] == 200 and result["data"]:
            template = env.get_template("ship-rank.html")
            result_data = {"data": result["data"], "shipInfo": shipInfo}
            content = await template.render_async(result_data)
            return content
        else:
            return None
    except (TimeoutError, ConnectTimeout):
        logger.warning(traceback.format_exc())
        return None
    except Exception:
        logger.error(traceback.format_exc())
        return None



import traceback
from asyncio.exceptions import TimeoutError
from pathlib import Path

import orjson
from httpx import ConnectTimeout
from nonebot.log import logger

from ..HttpClient_pool import client_default

dir_path = Path(__file__).parent


async def get_pupu_msg():
    try:
        url = "https://v1.hitokoto.cn"
        params = {}
        resp = await client_default.get(url, params=params, timeout=5)
        result = orjson.loads(resp.content)
        if resp.status_code == 200:
            return result["hitokoto"]
        else:
            return "噗噗出问题了>_<"
    except (TimeoutError, ConnectTimeout):
        logger.warning(traceback.format_exc())
    except Exception:
        logger.error(traceback.format_exc())
        return "噗噗出问题了>_<"



import re
import time
import traceback
from asyncio.exceptions import TimeoutError
from typing import List

import jinja2
import orjson
from httpx import ConnectTimeout
from nonebot.adapters.onebot.v11 import ActionFailed, Bot, MessageSegment
from nonebot.log import logger
from nonebot_plugin_htmlrender import html_to_pic

from ..data_source import (
    servers,
    set_damageColor,
    set_infoparams,
    set_upinfo_color,
    set_winColor,
    template_path,
)
from ..HttpClient_pool import client_yuyuko
from ..utils import match_keywords
from .publicAPI import check_yuyuko_cache, get_AccountIdByName

env = jinja2.Environment(
    loader=jinja2.FileSystemLoader(template_path), enable_async=True
)
env.globals.update(
    set_damageColor=set_damageColor,
    set_winColor=set_winColor,
    set_upinfo_color=set_upinfo_color,
    time=time,
    int=int,
    abs=abs,
    enumerate=enumerate,
)

async def get_AccountInfo(server_type, info, bot:Bot, ev):
    try:
        url, params = "", ""
        if isinstance(info, List):
            for i in info:
                if str(i).lower() == "me":
                    params = {"server": server_type, "accountId": int(ev.user_id)}
                    break
                match = re.search(r"CQ:at,qq=(\d+)", i)
                if match:
                    params = {"server": server_type, "accountId": int(match.group(1))}
                    break
            if not params and len(info) == 2:
                param_server, info = await match_keywords(info, servers)
                if param_server:
                    param_accountid = await get_AccountIdByName(
                        param_server, str(info[0])
                    )
                    if isinstance(param_accountid, int):
                        params = {"server": param_server, "accountId": param_accountid}
                    else:
                        return f"{param_accountid}"
                else:
                    return "服务器参数似乎输错了呢"
            elif params:
                logger.success(f"{params}")
            else:
                return "您似乎准备用游戏昵称查询，请检查参数中是否包含服务器和游戏昵称，以空格区分，如果您准备查询单船战绩，请带上ship参数"
        else:
            return "参数似乎出了问题呢"
        is_cache = await check_yuyuko_cache(params["server"], params["accountId"])
        if is_cache:
            logger.success("上报数据成功")
        else:
            logger.success("跳过上报数据，直接请求")
        url = "https://api.wows.shinoaki.com/public/wows/account/user/info"
        resp = await client_yuyuko.get(url, params=params, timeout=None)
        result = orjson.loads(resp.content)
        logger.success(f"本次请求总耗时{resp.elapsed.total_seconds()*1000}，服务器计算耗时:{result['queryTime']}")
        if result["code"] == 200 and result["data"]:
            template = env.get_template("wws-info.html")
            template_data = await set_infoparams(result["data"])
            content = await template.render_async(template_data)
            return await html_to_pic(
                content, wait=0, viewport={"width": 920, "height": 1000}
            )
        elif result["code"] == 403:
            return f"{result['message']}\n请先绑定账号"
        elif result["code"] == 500:
            return f"{result['message']}\n这是服务器问题，请联系雨季麻麻"
        else:
            return f"{result['message']}"
    except (TimeoutError, ConnectTimeout):
        logger.warning(traceback.format_exc())
        return "请求超时了，请过会儿再尝试哦~"
    except Exception:
        logger.error(traceback.format_exc())
        return "wuwuwu出了点问题，请联系麻麻解决"



import httpx
from httpx import Request, Response
from nonebot.log import logger

from .data_source import config

if config.proxy_on:
    proxy = {"https://": config.proxy}
else:
    proxy = {}
                   
yuyuko_headers = {
    'Authorization': config.api_token,
    'accept':'application/json',
    'Content-Type':'application/json',
}


async def before_request(request:Request):
    logger.info(f"{request.method} {request.url}")
    
async def after_response(response:Response):
    logger.info(f"本次响应的状态码:{response.status_code} {response.request}")
    
client_yuyuko = httpx.AsyncClient(
    headers=yuyuko_headers,
    event_hooks={
        "request":[before_request,],
        "response":[after_response,]
        }
    )

client_wg = httpx.AsyncClient(
    proxies=proxy
)

client_default = httpx.AsyncClient(
)


#import time
#import traceback
#from os import getcwd
#from pathlib import Path
#
#import jinja2
#from nonebot import get_driver
#from nonebot.adapters.onebot.v11 import MessageSegment
#from nonebot.log import logger
#from nonebot_plugin_htmlrender import html_to_pic
#from playwright.async_api import async_playwright
#
#from ..data_source import (
#    select_prvalue_and_color,
#    set_damageColor,
#    set_upinfo_color,
#    set_winColor,
#)
#from .publicAPI import get_all_shipList
#from ..utils import get_bot
#
#dir_path = Path(__file__).parent
#template_path = dir_path / "template"
#env = jinja2.Environment(
#    loader=jinja2.FileSystemLoader(template_path), enable_async=True
#)
#env.globals.update(
#    set_damageColor=set_damageColor,
#    set_winColor=set_winColor,
#    set_upinfo_color=set_upinfo_color,
#    time=time,
#    int=int,
#    abs=abs,
#    enumerate=enumerate,
#)
#
#headers = {"Authorization": get_driver().config.api_token}
#
## all_shipList = asyncio.run(get_all_shipList())
#
#
#async def send_realTime_message(data):
#    try:
#        global all_shipList
#        if not all_shipList:
#            all_shipList = await get_all_shipList()
#        bot = get_bot()
#        template = env.get_template("wws-realTime.html")
#        template_data = await set_realTime_params(data)
#        content = await template.render_async(template_data)
#        print(content)
#        async with async_playwright() as p:
#            browser = await p.chromium.launch()
#            page = await browser.new_page()
#            await page.goto(f"file://{getcwd()}")
#            await page.set_content(content, wait_until="networkidle")
#            img = await page.screenshot(full_page=True)
#            await browser.close()
#        await bot.send_group_msg(
#            group_id=639178962,
#            message=f"[测试功能]雨季刚刚进入了一场战斗\n{MessageSegment.image(img)}",
#        )
#    except Exception:
#        logger.error(traceback.format_exc())
#        return
#
#
#async def set_realTime_params(data):
#    try:
#        player_count = len(data["infoList"])
#        for each_player in data["infoList"]:
#            each_player["shipImgSmall"] = None
#            for each_ship in all_shipList:
#                if each_ship["id"] == each_player["shipId"]:
#                    if each_ship["shipNameCn"]:
#                        each_player["shipName"] = each_ship["shipNameCn"]
#                    else:
#                        each_player["shipName"] = each_ship["name"]
#                    each_player["shipImgSmall"] = each_ship["imgSmall"]
#                    each_player["shipIdValue"] = f"{each_ship['shipIdValue']}"
#                    break
#            if each_player["pvp"]:
#                (
#                    each_player["pvp"]["pr_name"],
#                    each_player["pvp"]["pr_color"],
#                ) = await select_prvalue_and_color(each_player["pvp"]["pr"])
#            if each_player["ship"]:
#                (
#                    each_player["ship"]["pr_name"],
#                    each_player["ship"]["pr_color"],
#                ) = await select_prvalue_and_color(each_player["ship"]["pr"])
#        data["player_count"] = player_count
#        data["template_path"] = template_path
#        logger.success(data)
#        return data
#    except Exception:
#        logger.error(traceback.format_exc())
#        return None
#
#
#async def send_message(content):
#    bot = get_bot()
#    img = await html_to_pic(content, wait=0, viewport={"width": 1800, "height": 1000})
#    await bot.send_group_msg(group_id=574432871, message=MessageSegment.image(img))
